import React, { useRef, useState, useEffect } from "react";
import { PageContainer } from '@ant-design/pro-layout';
import { GatewayOutlined, PlusOutlined } from '@ant-design/icons';
import ProTable from '@ant-design/pro-table';
import { Button, Form, Input, Select, Drawer, message, Col, Row,Popconfirm } from 'antd';
import styles from "./index.less";
import '@wangeditor/editor/dist/css/style.css'
import { Editor, Toolbar } from '@wangeditor/editor-for-react'
import axios from 'axios';
import cardAPI from "./service";
import GateSetUp from './components/gateSetUp';
 import SetGateFood from './components/setGateFood';


/**
 * 档口管理
 * @returns
 */
const Gate = () => {
  const actionRef = useRef();
  const [modalForm] = Form.useForm();
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [currentOption, setCurrentOption] = useState({});
  const [GateSetUpIsVisible, GateSetUpVisible] = useState(false);
  const [SetGateFoodIsVisible, setGateFoodVisible] = useState(false);
  const [storeList, setStoreList] = useState([]);
  const [selectedStore, setSelectedStore] = useState('');
  const [current, setCurrent] = useState(1);
  const [pageSize, setPageSize] = useState(10);

  const [gateSetUp, setGateSetUp] = useState([]);
  const [gateFoodSet, setGateFoodSet] = useState([]);


  // editor 实例
  const [editor, setEditor] = useState(null);
  // 编辑器内容
  const [html, setHtml] = useState('');
  // 工具栏配置
  const toolbarConfig = {};
  // 编辑器配置
  const editorConfig = {
    placeholder: '请输入大屏横幅...',
    MENU_CONF: {
      fontSize: {
        fontSizeList: [
          '10px', '20px', '40px', '60px', '80px', '100px', '150px', '180px', '200px',
        ]
      },
      uploadImage: {
        async customUpload(file, insertFn) {
          // file 即选中的文件
          // 自己实现上传，并得到图片 url alt href
          //覆盖action 上传之前获取上传地址
          let index = file.name.lastIndexOf(".");
          let ext = file.name.substr(index + 1);
          let fileData = null;
          cardAPI.GetCosRequestURL({ directory: "kitchen", fileExtension: ext, method: "PUT" }).then((r) => {
            const action = r.allUrl;
            const reader = new FileReader();
            reader.readAsArrayBuffer(file);
            reader.onload = (e) => {
              fileData = e.target.result;
              axios.put(action, fileData).then(response => {
                if (response.status == 200 || response.statusText == 'OK') {
                  // 最后插入图片
                  insertFn(r.seeUrl, r.seeUrl, r.seeUrl);
                  message.success('上传成功！');
                }
              });
            };
          });

        }
      }
    }
  }

  // 及时销毁 editor ，重要！
  useEffect(() => {
    return () => {
      if (editor == null) return
      editor.destroy()
      setEditor(null)
    }
  }, [editor])


//获取设置屏幕显示
const GetGateSetUp =async (gateId) => {
  const response = await cardAPI.GetGateSetUp({"gateId": gateId});
  const result = [];
  response.data.forEach(element => {
    result.push(element.key);
  });
  setGateSetUp(result);
}

//获取菜品显示
const GetGateFoodList =async (gateId) => {
  const response = await cardAPI.GetGateFoodList( gateId);
  const result = [];
  
  response.data.forEach(element => {
    result.push(element.foodId);
  });
  setGateFoodSet(result);
}


  /**
   * 点击编辑按钮
   * @param {*} record
   */
  const onEditTableRow = (record) => {
    setCurrentOption(record);
    setIsModalOpen(true);
    setHtml(record.remaek);
    modalForm.setFieldsValue(record);
  }
  /**
   * 设置界面显示
   * @param {*} record
   */
  const onGateSet = (record) => {
    setCurrentOption(record);
    GateSetUpVisible(true);
  }
  const setGateFood = (record) => {
    setCurrentOption(record);
    setGateFoodVisible(true);
  }
  

  /**
   * 点击新建
   */
  const onCreateTableRow = () => {
    setIsModalOpen(true);
    if (editor) {
      editor.setHtml('');
    }
    setHtml('');
    modalForm.resetFields();
  }


  /**
   * 提交表单
   */
  const onFinish = async (values) => {
    if (values.id) {
      values.remaek = html;
      const response = await cardAPI.UpdateGateInfo(values);
      if (response.statusCode === 200) {
        message.success('更新档口成功！');
        setIsModalOpen(false);
        actionRef.current.reload();
      } else {
        message.error(response.errors || '更新失败');
      }
    } else {
      values.remaek = html;
      values.status=0;
      const response = await cardAPI.AddGate(values);
      if (response.statusCode === 200) {
        message.success('新增档口成功！');
        setIsModalOpen(false);
        actionRef.current.reload();
      } else {
        message.error(response.errors || '新增失败');
      }
    }
  }

  const columns = [
    {
      title: '档口名称',
      dataIndex: 'name',
      ellipsis: true,
    },
    {
      title: '归属场景',
      dataIndex: 'storeId',
      render: (_, record) => {
        const find = storeList.find(item => item.id === record.storeId);
        if (find) {
          return <div>{find.name}</div>
        }
      }
    },
    {
      title: '属性',
      dataIndex: 'mode',
      valueType: 'select',
      valueEnum: {
        1: {
          text: '固定',
          status: 'Success',
        },
        2: {
          text: '自由设定',
          status: 'Success',
        }
      },
    },
    {
      title: '金额',
      dataIndex: 'price',
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueType: 'select',
      valueEnum: {
        0: {
          text: '正常',
          status: 'Success',
        },
        1: {
          text: '停用',
          status: 'Error',
        },
        2: {
          text: '删除',
          status: 'Error',
        }
      },
    },
    {
      title: '操作',
      valueType: 'option',
      key: 'option',
      fixed: 'right',
      width: 300,
      render: (text, record, _, action) => [
        <a onClick={() => onEditTableRow(record)}>更新</a>,
        <a onClick={async () =>{await GetGateFoodList(record.id);setGateFood(record)} }>设置菜品</a>,
        <a onClick={async ()=>{await GetGateSetUp(record.id);onGateSet(record)}}>设置屏幕显示</a>,
        <Popconfirm
        key="delete"
        title={`确定要删除吗？`}
        onConfirm={async () => {
          var res = await cardAPI.Del(record.id);
          if (res.data) {
            message.success('删除成功');
            actionRef.current.reload();
          } else {
            message.error('删除失败');
          }
        }}
        okText="确定"
        cancelText="取消"
      >
        <a href="#">删除</a>
      </Popconfirm>
      ],
    },
  ];

  /**
   * 获取店铺列表
   */
  const onFetchStoreList = async () => {
    const response = await cardAPI.GetAllStore();
    if (response.statusCode == "200") {
      setStoreList(response.data);
      setSelectedStore(response.data[0].id);
      actionRef.current.reload();
    } else {
      message.error(response.msg || '获取场景列表失败');
    }
  }

  useEffect(() => {
    onFetchStoreList();
  }, []);

  return (
    <PageContainer  header={{
      title: '',
      breadcrumb: {},
    }}>
      <div className={styles.member_card_container}>
        <ProTable
          columns={columns}
          actionRef={actionRef}
          pagination={{
            pageSize: pageSize,
            onChange: (page) => setCurrent(page),
          }}
          scroll={{
            x: 1300,
          }}
          request={
            async () => {
              if (selectedStore) {
                const response = await cardAPI.GetGateListByStorePage(selectedStore, current, pageSize);
                if (response.statusCode === 200) {
                  return {
                    data: response.data.data,
                    success: true,
                    total: response.data.total
                  }
                }
              }
            }
          }
          cardBordered
          editable={{
            type: 'multiple',
          }}
          rowKey="id"
          search={false}
          options={{
            setting: {
              listsHeight: 400,
            },
          }}

          dateFormatter="string"
          headerTitle="档口管理"
          toolBarRender={() => [
            <div className={styles.table_search_item}>
              <div>
                当前场景：
              </div>
              <Select style={{ width: 300 }} value={selectedStore} onChange={(value) => {
                setSelectedStore(value);
                actionRef.current.reload();
              }}>
                {
                  storeList.map(item => {
                    return <Option value={item.id} key={item.id}>{item.name}</Option>
                  })
                }
              </Select>
            </div>,
            <Button key="button" icon={<PlusOutlined />} type="primary" onClick={()=>{setCurrentOption({});onCreateTableRow()}}>
              新建
            </Button>
          ]}
        />
        <Drawer destroyOnClose width='85%' title={currentOption.id ? '更新' : '新增'} visible={isModalOpen} onClose={() => setIsModalOpen(false)}>
          <Form
            name="basic"
            onFinish={onFinish}
            form={modalForm}
            labelCol={{ span: 4 }}
          >
            <Form.Item
              label="id"
              name="id"
              hidden={true}
            >
              <Input size="large" />
            </Form.Item>

            <Row>
              <Col xs={12} sm={12} md={12} lg={12} xl={12}>
                <Form.Item
                  label="档口名称"
                  name="name"
                  rules={[
                    {
                      required: true,
                      message: '请输入档口名称！',
                    },
                  ]}
                >
                  <Input size="large" />
                </Form.Item>
              </Col>
              <Col xs={12} sm={12} md={12} lg={12} xl={12}>
                <Form.Item
                  label="归属场景"
                  name="storeId"
                  rules={[
                    {
                      required: true,
                      message: '请选择归属场景！',
                    },
                  ]}
                >
                  <Select size="large">
                    {
                      storeList.map(store => {
                        return (
                          <Select.Option key={store.id} value={store.id}>{store.name}</Select.Option>
                        )
                      })
                    }
                  </Select>
                </Form.Item>
              </Col>
              <Col xs={12} sm={12} md={12} lg={12} xl={12}>
                <Form.Item
                  label="属性"
                  name="mode"
                  rules={[
                    {
                      required: true,
                      message: '请选择属性！',
                    },
                  ]}
                >
                  <Select size="large">
                    <Select.Option value={1}>固定金额</Select.Option>
                    <Select.Option value={2}>自由设定</Select.Option>
                  </Select>
                </Form.Item>
              </Col>
              <Col xs={12} sm={12} md={12} lg={12} xl={12}>

                <Form.Item
                  noStyle
                  shouldUpdate={(prevValues, currentValues) =>
                    prevValues.mode !== currentValues.mode
                  }  >
                  {({ getFieldValue }) =>
                    (getFieldValue('mode') == '1') ? (
                      <Form.Item
                        label="金额"
                        name="price"
                        rules={[
                          {
                            required: true,
                            message: '请输入金额！',
                          },
                        ]}
                      >
                        <Input size="large" />
                      </Form.Item>

                    ) : null
                  }
                </Form.Item>

              </Col>
              <Col xs={12} sm={12} md={12} lg={12} xl={12}>
                {/* <Form.Item
                  label="状态"
                  name="status">
                  <Select size="large" defaultValue={1}>
                    <Option value={0}>正常</Option>
                    <Option value={1}>禁用</Option>
                  </Select>
                </Form.Item> */}
                <Form.Item
                  noStyle
                  shouldUpdate={(prevValues, currentValues) =>
                    prevValues.mode !== currentValues.mode
                  }  >
                  {({ getFieldValue }) =>
                    (currentOption.id) ? (
                      <Form.Item
                        label="状态"
                        name="status">
                        <Select size="large" defaultValue={0}>
                          <Option value={0}>正常</Option>
                          <Option value={1}>停用</Option>
                        </Select>
                      </Form.Item>
                    ) : null
                  }
                </Form.Item>


              </Col>
            </Row>
            <div style={{ border: '1px solid #ccc', zIndex: 100 }}>
              <Toolbar
                editor={editor}
                defaultConfig={toolbarConfig}
                mode="default"
                style={{ borderBottom: '1px solid #ccc' }}
              />
              <Editor
                defaultConfig={editorConfig}
                value={html}
                onCreated={setEditor}
                onChange={editor => setHtml(editor.getHtml())}
                mode="default"
                style={{ height: '500px', overflowY: 'hidden' }}
              />
            </div>
            <Form.Item>
              <Button type="primary" htmlType="submit" style={{ marginTop: '10px' }}>
                确定
              </Button>
            </Form.Item>
          </Form>
        </Drawer>
        {
          GateSetUpIsVisible&& <GateSetUp
          shows={GateSetUpIsVisible}
          values={currentOption}
          actionRef={actionRef}
          gateSetUp={gateSetUp}
          onCancel={() => {
            GateSetUpVisible(false);
          }}
        />
        }
        {SetGateFoodIsVisible && <SetGateFood
          shows={SetGateFoodIsVisible}
          values={currentOption}
          actionRef={actionRef}
          gateFoodSet={gateFoodSet}
          onCancel={() => {
            setGateFoodVisible(false);
          }}
        />}
       

      </div>
    </PageContainer>
  )
}

export default Gate;
